FromRow

Trait FromRow 

pub trait FromRow: Sized {
    // Required method
    fn from_values(values: &[Value]) -> Result<Self>;
}
Trait for types that can be constructed from a database row

Required Methods

fn from_values(values: &[Value]) -> Result<Self>

Try to construct this type from a vector of Values

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors