FromValue

Trait FromValue 

pub trait FromValue: Sized {
    // Required method
    fn from_value(value: &Value) -> Result<Self>;
}
Trait for types that can be created from a database Value

Required Methods

fn from_value(value: &Value) -> Result<Self>

Try to convert a database Value to this type

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl FromValue for bool

Source

fn from_value(value: &Value) -> Result<Self>

Source

impl FromValue for f64

Source

fn from_value(value: &Value) -> Result<Self>

Source

impl FromValue for i32

Source

fn from_value(value: &Value) -> Result<Self>

Source

impl FromValue for i64

Source

fn from_value(value: &Value) -> Result<Self>

Source

impl FromValue for String

Source

fn from_value(value: &Value) -> Result<Self>

Source

impl FromValue for Vec<u8>

Source

fn from_value(value: &Value) -> Result<Self>

Source

impl<T: FromValue> FromValue for Option<T>

Source

fn from_value(value: &Value) -> Result<Self>

Implementors