pub trait FromValue: Sized {
// Required method
fn from_value(value: &Value) -> Result<Self>;
}Expand description
Trait for types that can be created from a database Value
Required Methods
Sourcefn from_value(value: &Value) -> Result<Self>
fn from_value(value: &Value) -> Result<Self>
Try to convert a database Value to this type
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.